@@ -1,4 +1,6 @@
-/* -*- mode: c; c-basic-offset: 8 -*- */
+/* -*- Mode: C; c-basic-offset: 8; indent-tabs-mode: nil -*- */
+/* vim: set filetype=c tabstop=8 shiftwidth=4 expandtab: */
+
 /*
     ecl-cmp.h  -- Include file for compiled code.
 */
@@ -14,14 +16,23 @@
     See file '../Copyright' for full details.
 */
 
+#ifndef __CYGWIN__
+/* Recent versions of cygwin do not define fd_set when WINSOCKAPI is
+ * defined */
 #define _WINSOCKAPI_
+#endif /* __CYGWIN__ */
+/* Disable a couple of clang's more annoying diagnostics */
+#pragma clang diagnostic ignored "-Wreturn-type"
+#pragma clang diagnostic ignored "-Wunused-value"
+#pragma clang diagnostic ignored "-Wparentheses-equality"
+
 #include <ecl/ecl.h>
 #include <math.h> /* for inline mathematics */
 #include <ecl/ecl-inl.h>
 
 #define TRAMPOLINK(narg, vv, lk, cblock) \
-	cl_va_list args; cl_va_start(args, narg, narg, 0); \
-	return(_ecl_link_call(vv, (cl_objectfn *)lk, cblock, narg, args))
+        ecl_va_list args; ecl_va_start(args, narg, narg, 0); \
+        return(_ecl_link_call(vv, (cl_objectfn *)lk, cblock, narg, args))
 
 enum ecl_locative_type {
         _ecl_object_loc = 0,
@@ -31,9 +42,9 @@ enum ecl_locative_type {
         _ecl_float_loc,
         _ecl_double_loc
 #ifdef ECL_SSE2
-	, _ecl_int_sse_pack_loc
-	, _ecl_float_sse_pack_loc
-	, _ecl_double_sse_pack_loc
+        , _ecl_int_sse_pack_loc
+        , _ecl_float_sse_pack_loc
+        , _ecl_double_sse_pack_loc
 #endif
 };
 
@@ -41,3 +52,6 @@ struct ecl_var_debug_info {
         const char *name;
         uint8_t type;
 };
+
+#define _ecl_check_narg(n) \
+        do { if (ecl_unlikely(narg != (n))) FEwrong_num_arguments_anonym();} while(0)
